@@ -29,11 +29,11 @@ def main():
 	#obj.widequerychart('graph query columns eg2',obj.schwiz.dbthings.sqlite_db,sql)
 
 	#charter().csv_querychart('sales.csv','SELECT cal_dt,sales_amt,cost FROM sales.csv ORDER BY cal_dt')
-	charter().csv_widequerychart('widesales.csv',"SELECT legend," + '"2023/03/29","2023/03/30","2023/03/31","2023/04/01" FROM widesales.csv')
+	#charter().csv_widequerychart('widesales.csv',"SELECT legend," + '"2023/03/29","2023/03/30","2023/03/31","2023/04/01" FROM widesales.csv')
 
 
 	#charter().showcsv('sales.csv','SELECT cal_dt FROM sales.csv ORDER BY cal_dt')
-	#charter().showcsv('sales.csv')
+	#charter().showcsv('widesales.csv','SELECT * FROM widesales.csv')
 
 class charter():
 	def __init__(self):
@@ -48,13 +48,13 @@ class charter():
 	# cost      8.55       18.45      15.35      19.55      
 	# sales_amt 10.99      15.99      13.99      17.99      
 	#
-	def csv_widequerychart(self,csv_filename,query):
+	def csv_widequerychart(self,csv_filename,query,xlabel='points',ylabel='Amounts'):
 		self.schwiz.createload_sqlite_from_csv(csv_filename)
 		tablename = self.schwiz.lastcall_tablename
 		newquery = query.replace(csv_filename,tablename)
 		title = csv_filename
 
-		self.widequerychart(title,self.schwiz.dbthings.sqlite_db,newquery)
+		self.widequerychart(title,self.schwiz.dbthings.sqlite_db,newquery,xlabel,ylabel)
 
 		self.schwiz.dbthings.sqlite_db.execute('DROP TABLE ' + tablename)
 
@@ -67,7 +67,7 @@ class charter():
 	# 2023/03/31,booze,dave,20.99,2.35
 	# 2023/04/01,food,dave,5.99,43.25
 	#
-	def csv_querychart(self,csv_filename,query):
+	def csv_querychart(self,csv_filename,query,xlabel='',ylabel='Amounts'):
 		self.schwiz.createload_sqlite_from_csv(csv_filename)
 		tablename = self.schwiz.lastcall_tablename
 		newquery = query.replace(csv_filename,tablename)
@@ -163,9 +163,9 @@ class charter():
 	# 2023/04/01 17.99     19.55 
 	# 
 
-	def querychart(self,title,db,query):
+	def querychart(self,title,db,query,xlabel='',ylabel='Amounts'):
 		plt.title(title)
-		plt.ylabel('Amounts')
+		plt.ylabel(ylabel)
 		data = []
 		xaxis = []
 
@@ -184,7 +184,10 @@ class charter():
 			else:
 				skippedone = True
 
-		plt.xlabel(column_names[0])
+		if xlabel != '':
+			plt.xlabel(xlabel)
+		else:
+			plt.xlabel(column_names[0])
 
 		for row in onerundata:
 			data.append(row)
